@@ -1,6 +1,7 @@
 # UTF-8 encoded Traditional Chinese language file for use with Oddmuse
 #
-# Copyright (c) 2003, 2004  wctang <wctang@csie.nctu.edu.tw>.
+# Copyright (c) 2003, 2004  wctang <wctang@csie.nctu.edu.tw>
+# Copyright (c) 2007  Wei Ren Wang <weithenn@gmail.com>
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -17,14 +18,16 @@
 #
 # This translation was last checked for Oddmuse version 1.504.
 #
-$ModulesDescription .= '<p>$Id: chinese-utf8.pl,v 1.10 2007/08/19 11:42:07 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: chinese-utf8.pl,v 1.12 2009/06/07 19:30:37 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
+Include normal pages
+包含正常頁面
 Reading not allowed: user, ip, or network is blocked.
 禁止讀取：使用者、ip 或是網路已被禁止連線。
 Login
-
+登入
 Error
-
+錯誤
 %s calls
 
 Could not create %s
@@ -38,7 +41,7 @@ This page contains an uploaded file:
 Recursive include of %s!
 
 Clear Cache
-
+清除快取
 Main lock obtained.
 取得主要鎖定。
 Main lock released.
@@ -66,11 +69,9 @@ No items found in %s.
 Click to edit this page
 按此即可編輯此頁面
 CGI Internal error: %s
-
+CGI 內部錯誤: %s
 Invalid action parameter %s
 無效的動作參數 %s
-Invalid URL.
-無效的 URL 。
 Page name is missing
 頁面不存在
 Page name is too long: %s
@@ -81,16 +82,14 @@ Invalid Page %s (must not end with .lck)
 無效的頁面名稱 %s (不可使用 .lck 做為結尾)
 Invalid Page %s
 無效的頁面名稱 %s
-Preview:
-預覽：
-Preview only, not yet saved
-現在是預覽模式，尚未儲存
+Too many redirections
+
+No redirection for old revisions
+
+Invalid link pattern for #REDIRECT
+
 Please go on to %s.
 請繼續前住 %s 。
-All changes for %s
-
-No updates since %s
-自 %s 以來沒有修改
 Updates since %s
 自 %s 以來的修改
 Updates in the last %s days
@@ -104,9 +103,9 @@ List latest change per page only
 List all changes
 列出所有的修改
 Skip rollbacks
-
+跳過恢復的版本
 Include rollbacks
-
+包含恢復的版本
 List only major changes
 只列出主要的修改
 Include minor changes
@@ -124,15 +123,15 @@ RSS with pages and diff
 Filters
 過濾器
 Title:
-
+標題:
 Title and Body:
-
+標題和內文:
 Username:
 使用者名稱：
 Host:
 來源主機：
 Follow up to:
-
+後續行動:
 Language:
 語文：
 Go!
@@ -143,38 +142,38 @@ rollback
 回復
 new
 新增
+All changes for %s
+所有修改頁面 %s
 from %s
 自 %s
-: 
-
 This page is too big to send over RSS.
-
+此頁面太大無法透過 RSS 傳送
 History of %s
 %s 的歷史記錄
 Compare
 比較
 Deleted
-
+已刪除
 Mark this page for deletion
-
+標記為準備刪除的頁面
 No other revisions available
-
+無其他版本
 current
-
+目前
 Revision %s
 第 %s 版本
 Contributors to %s
-
+編寫 %s 的作者
 Missing target for rollback.
 找不到要回復的目標
 Target for rollback is too far back.
 要回復的目標已太久以前了。
 A username is required for ordinary users.
-
+需使用普通用戶名稱
 Rolling back changes
 回復修改
 The two revisions are the same.
-
+二個版本相同
 Editing not allowed for %s.
 不允許編輯 %s 。
 Rollback to %s
@@ -182,7 +181,7 @@ Rollback to %s
 %s rolled back
 %s 已回復
 to %s
-
+到 %s
 Index of all pages
 所有頁面的索引
 Wiki Version
@@ -198,37 +197,41 @@ Unlock site
 Lock site
 網站鎖定
 Install CSS
-
+安裝 CSS
 Unlock %s
-
+解鎖 %s
 Lock %s
-
+鎖定 %s
 Administration
-
+管理 Oddmuse
 Actions:
-
+操作:
 Important pages:
-
+重要頁面:
 To mark a page for deletion, put <strong>%s</strong> on the first line.
-
+在該頁首行加入 <strong>%s</strong> 可將頁面標記為刪除
 [Home]
 [首頁]
 redirected from %s
 由 %s 轉址 
+%s: 
+
 Click to search for references to this page
 按下即可以搜尋參考至本頁的資料
 Cookie: 
-
+Cookie:
+Edit this page
+編輯本頁
+Preview:
+預覽：
+Preview only, not yet saved
+現在是預覽模式，尚未儲存
 Warning
 警告
 Database is stored in temporary directory %s
 資料庫現在是存放於暫存目錄 %s
 %s seconds
 %s 秒
-The same page on other sites:
-其他網站的相同頁面
-EditNearLinks
-
 Last edited
 最後編輯於
 Edited
@@ -239,8 +242,6 @@ by %s
 (比較差異)
 Edit revision %s of this page
 編輯本頁的第 %s 版本
-Edit this page
-編輯本頁
 e
 
 This page is read-only
@@ -252,7 +253,7 @@ View current revision
 View all changes
 列出所有的修改
 View contributors
-
+查看編寫者
 Homepage URL:
 首頁網址：
 s
@@ -270,13 +271,13 @@ f
 Replace:
 取代：
 Delete
-
+刪除
 Validate HTML
 驗證 HTML
 Validate CSS
 驗證 CSS
 Last edit
-
+最後編輯
 Difference between revision %1 and %2
 差異（從第 %1 版到%2）
 revision %s
@@ -284,9 +285,9 @@ revision %s
 current revision
 目前的版本
 Last major edit (%s)
-
+最後一個主要編輯 (%s)
 later minor edits
-
+後來小修改
 No diff available.
 沒有差異。
 Old revision:
@@ -294,7 +295,7 @@ Old revision:
 Changed:
 修改：
 Deleted:
-
+已刪除:
 Added:
 增加：
 to
@@ -314,11 +315,11 @@ Cannot open %s
 Cannot write %s
 無法寫入 %s
 Cannot create %s
-
+無法建立 %s
 Could not get %s lock
 無法取得 %s 鎖定
 The lock was created %s.
-
+建立鎖定 %s
 This operation may take several seconds...
 這個動作可能要花幾秒…
 Forced unlock of %s lock.
@@ -366,7 +367,7 @@ Summary:
 This change is a minor edit.
 這次的修改是次要的。
 Cancel
-
+取消
 Replace this file with text
 用文字來取代本檔
 Replace this text with a file
@@ -394,31 +395,19 @@ This operation is restricted to site editors only...
 This operation is restricted to administrators only...
 這個動作限定只允許管理者使用…
 SampleUndefinedPage
-
+未定義頁面
 Sample_Undefined_Page
-
+未定義頁面
 Rule "%1" matched "%2" on this page.
 本頁的 "%2" 符合規則 "%1"。
 Reason: %s.
-
+原因: %s
 Reason unknown.
-
-Without normal pages
-
-Include normal pages
-
-Without permanent anchors
-
-Include permanent anchors
-
-Without near pages
-
-Include near pages
-
+未知原因
+Filter:
+過濾規則:
 (for %s)
 (列出 %s )
-Filter:
-
 %s pages found.
 找到 %s 個頁面。
 Replaced: %s
@@ -427,16 +416,6 @@ Search for: %s
 搜尋：%s
 View changes for these pages
 參閱這些頁面的更動
-Search sites on the %s as well
-也搜尋列在 %s 上的網站
-and
-和
-or
-或
-Fetching results from %s:
-由 %s 取回的結果：
-Near pages:
-近端頁面：
 last updated
 最後更新於
 by
@@ -450,7 +429,7 @@ Browser reports no file type.
 The page contains banned text.
 本頁含有一些禁止出現的文字。
 No changes to be saved.
-
+沒有可以存取的變更。
 This page was changed by somebody else %s.
 本頁在 %s 已被人修改過。
 The changes conflict.  Please check the page again.
@@ -474,7 +453,7 @@ ancestor
 other
 別人的
 Run Maintenance
-
+執行維護 Oddmuse
 Maintenance not done.
 無法進行管理。
 (Maintenance can only be done once every 12 hours.)
@@ -497,8 +476,6 @@ Note: This error is normal if no changes have been made.
 如果還沒有做過任何修改的話，則不用理會這個錯誤訊息。
 Moving %s log entries.
 移除了 %s 個記錄項目。
-Getting page index file for %s.
-自 %s 取得頁面索引資料。
 Set or Remove global edit lock
 設定或移除整個網站的編輯鎖定
 Edit lock created.
@@ -512,29 +489,19 @@ Lock for %s created.
 Lock for %s removed.
 已移除 %s 的鎖定。
 Displaying Wiki Version
+顯示 Wiki 主機相關套件版本
+Debugging Information
 
-Show dependencies
-顯示相依函式庫
 Inter links:
 內部連結：
-Near links:
-近端連結：
-Show parsed link data
-顯示特殊連結設定
 Too many connections by %s
 太多來自 %s 的連線
 Please do not fetch more than %1 pages in %2 seconds.
 請不要在 %2 秒內抓取超過 %1 頁的資料。
 Check whether the web server can create the directory %s and whether it can create files in it.
 請確認網站伺服器是否可建立 %s 目錄，並且在其中建立檔案。
-anchor first defined here: %s
-錨點已被定義於 %s
-Click to search for references to this permanent anchor
-按下即可搜尋此錨點的相關資料
-the page %s also exists
-也存在一個叫 %s 的頁面
 Copy one of the following stylesheets to %s:
-
+複製以下 CSS 模版至 %s
 Deleting %s
 正在刪除 %s
 Deleted %s
@@ -546,43 +513,47 @@ The page %s does not exist
 The page %s already exists
 頁面 %s 已存在
 Cannot rename %1 to %2
-
+無法將 %1 重新命名為 %2
 Renamed to %s
-更名為 %s
+重新命名為 %s
 Renamed from %s
-更名自 %s
+來自 %s 的重新命名
 Renamed %1 to %2.
 已將 %1 更名為 %2 。
 Immediately delete %s
-
+立即刪除 %s
 Rename %s to:
-
+將 %s 重新命名為:
 Learn more...
-
+更多...
 Complete Content
 完整內容
 The main page is %s.
 首頁是 %s 。
 Archive:
-
+檔案:
 Rebuild BackLink database
-
+重建 BackLink 資料庫
 Internal Page: 
-
+內部頁面:
 Pages that link to this page
+連結此頁面
+The search parameter is missing.
+
+Pages link to %s
 
 Cannot highlight the language %s.
 無法強調顯示 %s 。
 Recent Visitors
 最近的參訪者
 some action
-
+部份行為
 was here
-
+在這裡
 and read
-
+閱讀
 Illegal year value: Use 0001-9999
-
+指定的年份無效:請使用 0001-9999 之間的數字
 The match parameter is missing.
 未指定 match 參數。
 Page Collection for %s
@@ -594,51 +565,51 @@ Next
 Calendar %s
 %s 年曆
 Su
-
+星期日
 Mo
-
+星期一
 Tu
-
+星期二
 We
-
+星期三
 Th
-
+星期四
 Fr
-
+星期五
 Sa
-
+星期六
 January
-
+一月
 February
-
+二月
 March
-
+三月
 April
-
+四月
 May
-
+五月
 June
-
+六月
 July
-
+七月
 August
-
+八月
 September
-
+九月
 October
-
+十月
 November
-
+十一月
 December
-
+十二月
 set %s
-
+設定 %s
 unset %s
-
+解除設定 %s
 Clustermap
-
+叢集頁面
 Pages without a Cluster
-
+不包含叢集頁面
 Comments on 
 評論關於
 Comment on 
@@ -646,13 +617,13 @@ Comment on
 Compilation for %s
 %s 的彙整
 Compilation tag is missing a regular expression.
-
+匯編的標記缺少一個正規表示式
 List spammed pages
-
+列出 SPAM 頁面
 Despamming pages
-正在去除 spam 頁面
+正在去除 SPAM 頁面
 Spammed pages
-
+SPAM 廣告頁面
 Cannot find revision %s.
 無法取得版本 %s 。
 Revert to revision %1: %2
@@ -662,39 +633,37 @@ Marked as %s.
 Cannot find unspammed revision.
 找不到未被 spam 的版本。
 Recover Draft
-
+還原草稿
 No text to save
-
+沒有儲存文字
 Draft saved
-
+草稿已儲存
 Draft recovered
-
+草稿已還原
 No draft available to recover
-
+沒有可還原的草稿
 Save Draft
-
+儲存草稿
 Draft Cleanup
-
+清除草稿
 %1 was last modified %2 and was kept
-
+%1 最後修改 %2 及保存
 %1 was last modified %2 and was deleted
-
+%1 最後修改 %2 及刪除
 Unable to delete draft %s
-
+無法刪除草稿 %s
 Add Comment
-
+新增評論
 ordinary changes
-
+普通變更
 Matching page names:
-
-Footnotes:
-註解：
+匹配頁面的名稱:
 Could not find %1.html template in %2
 無法在 %2 找到 %1.html 的範本
 Only Editors are allowed to see this hidden page.
-
+只允許編輯者能看到此隱藏頁面
 Only Admins are allowed to see this hidden page.
-
+只允許管理者能看到此隱藏頁面
 Index
 索引
 Languages:
@@ -705,100 +674,106 @@ Define
 定義
 Full Link List
 完整連結列表
+List of locked pages
+
+Pages tagged with %s
+
 Template without parameters
 未指定 template 參數
 The template %s is either empty or does not exist.
 範本 %s 可能為空或不存在。
  -- defined on %s
-
+ -- 在 %s 中定義
 Local names defined on %1: %2
+定義本地名稱在 %1: %2
+Locked Pages
 
 Register for %s
-
+為 %s 註冊
 Please choose a username of the form "FirstLast" using your real name.
-
+請選擇符合您真實名字的 "FirstLast"
 The passwords do not match.
-
+密碼不正確
 The password must be at least %s characters.
-
+密碼必須有 %s 字
 That email address is invalid.
-
+無效的 E-Mail 地址
 The username %s has already been registered.
-
+使用者名稱 %s 已被註冊
 Your registration for %s has been submitted.
-
+您註冊的使用者名稱 %s 已提交
 Please allow time for the webmaster to approve your request.
-
+請等待一段時間網站管理者為盡快回應您的需求
 An email has been sent to "%s" with further instructions.
-
+E-Mail 已被送到 "%s" 等待進一步的指示
 There was an error saving your registration.
-
+存取的註冊資訊有一個錯誤
 An account was created for %s.
-
+使用者帳戶 %s 已建立
 Login to %s
-
+登入到 %s
 Username and/or password are incorrect.
-
+使用者名稱或密碼不正確
 Logged in as %s.
-
+登入為 %s
 Logout of %s
-
+登出 %s
 Logout of %s?
-
+登出 %s ?
 Logged out of %s
-
+已登出 %s
 You are now logged out.
-
+您已登出
 Register a new account
-
+註冊新使用者帳戶
 Logout
-
+登出
 Who am I?
-
+我是誰 ?
 Forgot your password?
-
+忘記您的密碼 ?
 Change your password
-
+變更您的密碼
 Approve pending registrations
-
+等待核准註冊
 Confirm Registration for %s
-
+確認註冊為 %s
 %s, your registration has been approved. You can now use your password to login and edit this wiki.
-
+%s, 您的註冊已被核准，現在您可以用你的密碼登入和編輯頁面。
 Confirmation failed.  Please email %s for help.
-
+確認失敗!!請發 E-mail 至 %s 尋求幫助
 Who Am I?
-
+我是誰 ?
 You are logged in as %s.
-
+您是登入為 %s
 You are not logged in.
-
+您尚未登入
 Reset Password
-
+重設密碼
 The password for %s was reset.  It has been emailed to the address on file.
-
+%s 密碼已重設，已發送 E-mail 至該地址
 There was an error resetting the password for %s.
-
+重設密碼時發生錯誤 %s
 The username "%s" does not exist.
-
+使用者名稱 "%s" 不存在
 Reset Password for %s
-
+重設密碼 %s
 Reset Password?
-
+重設密碼 ?
 Change Password for %s
-
+變更密碼 %s
 Change Password?
-
+變更密碼 ?
 Your current password is incorrect.
-
+您目前的密碼不正確
 Your password has been changed.
-
+您的密碼已變更
 Approve Pending Registrations for %s
-
+等待註冊 %s
 %s has been approved.
-
+%s 已核准
 There was an error approving %s.
-
+核准有一處錯誤 %s
 <ul>
 
 <li>%1 - %2</li>
@@ -806,36 +781,110 @@ There was an error approving %s.
 </ul>
 
 There are no pending registrations.
+沒有等候的註冊
+Invalid Mail %s: not saved.
+
+unsubscribe
+
+subscribe
+
+Email: 
+
+%s appears to be an invalid mail address
+
+Your mail subscriptions
+
+All mail subscriptions
+
+Subscriptions
+
+Show
+
+Subscriptions for %s:
+
+Unsubscribe
+
+There are no subscriptions for %s.
+
+Change email address
+
+Mail addresses are linked to unsubscription links.
+
+Subscribe to %s.
+
+Subscribe
+
+Subscribed %s to the following pages:
+
+The remaining pages do not exist.
+
+Unsubscribed %s from the following pages:
+
+You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.
 
 %s is not a legal name for a namespace
+%s 不是一個正常的命名空間
+Namespaces
 
+Getting page index file for %s.
+自 %s 取得頁面索引資料。
+Near links:
+近端連結：
+Search sites on the %s as well
+也搜尋列在 %s 上的網站
+Fetching results from %s:
+由 %s 取回的結果：
+Near pages:
+近端頁面：
+Include near pages
+包含相近的頁面
+EditNearLinks
+編輯接近連結
+The same page on other sites:
+其他網站的相同頁面
  (create locally)
-
+ (本地建立)
 image
 圖像
 download
 下載
+Backlinks
+
 Clearing Cache
 清除暫存
 Done.
-
+結束
 Generating Link Database
 產生連結資料庫
 The 404 handler extension requires the link data extension (links.pl).
-
+404 訊息，您需要安裝 (links.pl) 擴充模組
 LocalMap
-
+本地地圖
 No page id for action localmap
-
+在本地地圖內查詢不到頁面名稱
 Requested page %s does not exist
-
+請求的頁面 %s 不存在
 Local Map for %s
-
+頁面 %s 的本地地圖
 view
-
+查看
 Self-ban by %s
-
+被 %s 禁止
 You have banned your own IP.
+您禁止了自已的 IP Address
+OpenID Login
+
+Your identity is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
+
+Your homepage is set to %s.
+
+You have no homepage set.
+
+Homepage:
+
+Homepage is missing
+
+OpenID error %s
 
 Orphan List
 孤立頁面列表
@@ -847,67 +896,91 @@ Type
 類別
 Permalink to "%s"
 永久連結至 "%s"
+anchor first defined here: %s
+錨點已被定義於 %s
+the page %s also exists
+也存在一個叫 %s 的頁面
 There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
-
+建立 %s PDF 時發生錯誤，請停止下載動作並立即通知網站管理員。
 Someone else is generating a pdf for %s.  Please wait a minute and then try again.
-
+其它使用者正在建立 %s PDF，請過幾分鐘後在試試。
 Download this page as PDF
-
+下載本頁面 PDF
+Click to search for references to this permanent anchor
+按下即可搜尋此錨點的相關資料
+Include permanent anchors
+包含固定的錨點
 Portrait
 肖像
 Publish %s
-
+發表 %s
 No target wiki was specified in the config file.
-
+設定檔案中沒有設定目標(Target) Wiki
 The target wiki was misconfigured.
-
+目標(Target) Wiki 設定錯誤
 You did not answer correctly.
-
-Use the back button to return the previous page and try again.
-
+您沒有回答正確的答案
 To save this page you must answer this question:
+為了保存此頁面，您必須回答這個問題:
+Please type the following two words:
+
+Please answer this captcha:
 
 Referrers
 引用者
 All Referrers
 所有的引用者
 Tag
-
+標籤
 Rebuild index for searching
-
+重建搜尋索引檔
 Tag Cloud
-
+標籤雲
 Search::FreeText is not available on this system.
-
+搜尋::關鍵字不存在
 Rebuilding index not done.
-
+重建索引尚未完成
 (Rebuilding the index can only be done once every 12 hours.)
+(重建索引間隔為 12 小時)
+New Pages for Indexed Search
+
+List changes since %s
 
  ... 
 
 Search term missing.
-
+缺少搜尋項
 Result pages: 
-
+搜尋結果頁面:
 (%s results)
-
+(%s 結果)
 Tags:
-
+標籤:
 Tags: %s.
-
+標籤: %s
 No tags
+無標籤
+Page list for %s
 
 Slideshow:%s
-
+自動播放: %s
 Index of all small pages
-
+索引所有小頁面
 Static Copy
 靜態頁面備份
 Back to %s
 返回 %s
 Copy to %1 succeeded: %2.
-
+從 %2 複製到 %1 成功
 Copy to %1 failed: %2.
+從 %2 複製到 %1 失敗
+Feed for this tag
+
+Rebuild tag index
+
+list tags
+
+tag cloud
 
 Alternatively, use one of the following templates:
 或者，使用下列範本之一:
@@ -918,7 +991,7 @@ ID parameter is missing.
 Thread %s does not exist.
 討論緒 %s 不存在。
 Page %s does not contain a thread.
-
+頁面 %s 不包含討論主題
 Add
 加入
 URL parameter is missing.
@@ -932,12 +1005,32 @@ URL:
 Name:
 姓名:
 Too many instances.  Only %s allowed.
-
+太多請求，只允許 %s
 Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.
-
+系統忙碌中請稍後在試一次，可能有人正在執行維護動作或長期搜尋
 Contents
 內容
 Create a new page for today
+建立今日頁面
+Add Translation
+
+Added translation: %1 (%2)
+
+Translate %s
+
+Thank you for writing a translation of %s.
+
+Please indicate what language you will be using.
+
+Language is missing
+
+Suggested languages:
+
+Please indicate a page name for the translation of %s.
+
+More help may be available here: %s.
+
+Translated page: 
 
 This page is a translation of %s. 
 本頁是頁面 %s 的翻譯。
@@ -958,23 +1051,23 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 search
 搜尋
 Wanted Pages
-
+徵求頁面
 %s pages
-
+%s 頁面
 %s, referenced from:
-
+%s 引用自:
 Upload of %s file
-
+上傳 %s 檔案
 Blog
-
+日誌
 Matching pages:
-
+匹配頁面:
 New
-
+新增日誌
 Edit %s.
-
+編輯 %s
 Title: 
-
+標題:
 Tags: 
-
+標籤:
 END_OF_TRANSLATION
