@@ -16,8 +16,10 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-$ModulesDescription .= '<p>$Id: finnish-utf8.pl,v 1.10 2007/08/19 11:42:07 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: finnish-utf8.pl,v 1.11 2009/06/07 19:30:37 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
+Include normal pages
+
 Reading not allowed: user, ip, or network is blocked.
 Lukeminen ei ole sallittua: käyttäjä, IP tai verkko on estetty.
 Login
@@ -68,8 +70,6 @@ CGI Internal error: %s
 
 Invalid action parameter %s
 Virheellinen toiminto %s
-Invalid URL.
-Virheellinen URL.
 Page name is missing
 Sivun nimi puuttuu
 Page name is too long: %s
@@ -80,16 +80,14 @@ Invalid Page %s (must not end with .lck)
 Virheellinen sivu %s (pääte ei voi olla .lck)
 Invalid Page %s
 Virheellinen sivu %s
-Preview:
-Esikatselu:
-Preview only, not yet saved
-Pelkkä esikatselu, sivua ei ole tallennettu vielä
+Too many redirections
+
+No redirection for old revisions
+
+Invalid link pattern for #REDIRECT
+
 Please go on to %s.
 Siirtykää sivulle %s, kiitos.
-All changes for %s
-
-No updates since %s
-Ei päivityksiä %s jälkeen
 Updates since %s
 Päivitykset %s jälkeen
 Updates in the last %s days
@@ -142,10 +140,10 @@ rollback
 sivun palautus
 new
 uusi
+All changes for %s
+
 from %s
 %s:stä
-: 
-
 This page is too big to send over RSS.
 
 History of %s
@@ -214,20 +212,24 @@ To mark a page for deletion, put <strong>%s</strong> on the first line.
 [Etusivu]
 redirected from %s
 uudelleenohjattu sivulta %s
+%s: 
+
 Click to search for references to this page
 Klikkaa hakeaksesi viittauksia tälle sivulle
 Cookie: 
 
+Edit this page
+Muokkaa tätä sivua
+Preview:
+Esikatselu:
+Preview only, not yet saved
+Pelkkä esikatselu, sivua ei ole tallennettu vielä
 Warning
 Varoitus
 Database is stored in temporary directory %s
 Tietokanta on tallennettu väliaikaishakemistoon %s
 %s seconds
 %s sekuntia
-The same page on other sites:
-Sama sivu muilla sivustoilla:
-EditNearLinks
-MuokkaaLähiLinkkejä
 Last edited
 Viimeksi muokattu
 Edited
@@ -238,8 +240,6 @@ by %s
 (diff)
 Edit revision %s of this page
 Muokkaa tämän sivun versiota %s
-Edit this page
-Muokkaa tätä sivua
 e
 m
 This page is read-only
@@ -402,22 +402,10 @@ Reason: %s.
 
 Reason unknown.
 
-Without normal pages
-
-Include normal pages
-
-Without permanent anchors
-
-Include permanent anchors
-
-Without near pages
-
-Include near pages
+Filter:
 
 (for %s)
 (%s:lle)
-Filter:
-
 %s pages found.
 %s sivua löydetty.
 Replaced: %s
@@ -426,16 +414,6 @@ Search for: %s
 Etsi: %s
 View changes for these pages
 Näytä muutokset näille sivulle
-Search sites on the %s as well
-Etsi myös sivustoilla %s
-and
-ja
-or
-tai
-Fetching results from %s:
-Haetaan tulokset %s:stä :
-Near pages:
-Lähisivut:
 last updated
 viimeksi päivitetty
 by
@@ -496,8 +474,6 @@ Note: This error is normal if no changes have been made.
 Huom: Tämä virhe on normaali, jos muutoksia ei ole tehty.
 Moving %s log entries.
 Siirretään %s kirjausta.
-Getting page index file for %s.
-Haetaan sivun indeksitiedosto %s.
 Set or Remove global edit lock
 Aseta tai poista sivuston muokkauslukitus
 Edit lock created.
@@ -512,26 +488,16 @@ Lock for %s removed.
 Lukko %s:lle poistettu.
 Displaying Wiki Version
 
-Show dependencies
+Debugging Information
 
 Inter links:
 Kaukolinkit:
-Near links:
-Lähilinkit:
-Show parsed link data
-
 Too many connections by %s
 Liian monta yhteydenottoa %s:stä
 Please do not fetch more than %1 pages in %2 seconds.
 älä avaa yli %1 sivua %2 sekunnin aikana.
 Check whether the web server can create the directory %s and whether it can create files in it.
 Tarkista voiko www-palvelin luoda hakemiston %s ja voiko se luoda sivuja tähän hakemistoon.
-anchor first defined here: %s
-ankkuri nimetty ensimmäisen kerran täällä: %s
-Click to search for references to this permanent anchor
-Klikkaa etsiäksesi viittauksia tähän pysyvään ankkuriin
-the page %s also exists
-tämä sivu %s on myös olemassa
 Copy one of the following stylesheets to %s:
 
 Deleting %s
@@ -570,6 +536,10 @@ Internal Page:
 
 Pages that link to this page
 
+The search parameter is missing.
+
+Pages link to %s
+
 Cannot highlight the language %s.
 Kieltä %s ei voida merkitä
 Recent Visitors
@@ -686,8 +656,6 @@ ordinary changes
 
 Matching page names:
 
-Footnotes:
-Alaviitteet:
 Could not find %1.html template in %2
 
 Only Editors are allowed to see this hidden page.
@@ -704,6 +672,10 @@ Define
 Määritä
 Full Link List
 Täysi linkkilista
+List of locked pages
+
+Pages tagged with %s
+
 Template without parameters
 Pohja ilman parametrejä
 The template %s is either empty or does not exist.
@@ -712,6 +684,8 @@ Pohja %s on joko tyhjä tai ei ole olemassa.
 
 Local names defined on %1: %2
 
+Locked Pages
+
 Register for %s
 
 Please choose a username of the form "FirstLast" using your real name.
@@ -806,14 +780,74 @@ There was an error approving %s.
 
 There are no pending registrations.
 
+Invalid Mail %s: not saved.
+
+unsubscribe
+
+subscribe
+
+Email: 
+
+%s appears to be an invalid mail address
+
+Your mail subscriptions
+
+All mail subscriptions
+
+Subscriptions
+
+Show
+
+Subscriptions for %s:
+
+Unsubscribe
+
+There are no subscriptions for %s.
+
+Change email address
+
+Mail addresses are linked to unsubscription links.
+
+Subscribe to %s.
+
+Subscribe
+
+Subscribed %s to the following pages:
+
+The remaining pages do not exist.
+
+Unsubscribed %s from the following pages:
+
+You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.
+
 %s is not a legal name for a namespace
 
+Namespaces
+
+Getting page index file for %s.
+Haetaan sivun indeksitiedosto %s.
+Near links:
+Lähilinkit:
+Search sites on the %s as well
+Etsi myös sivustoilla %s
+Fetching results from %s:
+Haetaan tulokset %s:stä :
+Near pages:
+Lähisivut:
+Include near pages
+
+EditNearLinks
+MuokkaaLähiLinkkejä
+The same page on other sites:
+Sama sivu muilla sivustoilla:
  (create locally)
 
 image
 kuva
 download
 download
+Backlinks
+
 Clearing Cache
 Välimuistia tyhjennetään
 Done.
@@ -836,6 +870,20 @@ Self-ban by %s
 
 You have banned your own IP.
 
+OpenID Login
+
+Your identity is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
+
+Your homepage is set to %s.
+
+You have no homepage set.
+
+Homepage:
+
+Homepage is missing
+
+OpenID error %s
+
 Orphan List
 Orpojen sivujen lista
 Trail: 
@@ -846,12 +894,20 @@ Type
 Tyyppi
 Permalink to "%s"
 Pysyvä linkki "%s":ään
+anchor first defined here: %s
+ankkuri nimetty ensimmäisen kerran täällä: %s
+the page %s also exists
+tämä sivu %s on myös olemassa
 There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
 
 Someone else is generating a pdf for %s.  Please wait a minute and then try again.
 
 Download this page as PDF
 
+Click to search for references to this permanent anchor
+Klikkaa etsiäksesi viittauksia tähän pysyvään ankkuriin
+Include permanent anchors
+
 Portrait
 Avatar
 Publish %s
@@ -862,10 +918,12 @@ The target wiki was misconfigured.
 
 You did not answer correctly.
 
-Use the back button to return the previous page and try again.
-
 To save this page you must answer this question:
 
+Please type the following two words:
+
+Please answer this captcha:
+
 Referrers
 Viittaukset
 All Referrers
@@ -882,6 +940,10 @@ Rebuilding index not done.
 
 (Rebuilding the index can only be done once every 12 hours.)
 
+New Pages for Indexed Search
+
+List changes since %s
+
  ... 
 
 Search term missing.
@@ -896,6 +958,8 @@ Tags: %s.
 
 No tags
 
+Page list for %s
+
 Slideshow:%s
 
 Index of all small pages
@@ -908,6 +972,14 @@ Copy to %1 succeeded: %2.
 
 Copy to %1 failed: %2.
 
+Feed for this tag
+
+Rebuild tag index
+
+list tags
+
+tag cloud
+
 Alternatively, use one of the following templates:
 Vaihtoehtoisesti, käytä yhtä seuraavista pohjista:
 Thread: %s
@@ -938,6 +1010,26 @@ Contents
 Sisältö
 Create a new page for today
 
+Add Translation
+
+Added translation: %1 (%2)
+
+Translate %s
+
+Thank you for writing a translation of %s.
+
+Please indicate what language you will be using.
+
+Language is missing
+
+Suggested languages:
+
+Please indicate a page name for the translation of %s.
+
+More help may be available here: %s.
+
+Translated page: 
+
 This page is a translation of %s. 
 
 The translation is up to date.
