@@ -3,6 +3,7 @@
 # Copyright (c) 2003  Zajcev Evgeny
 # Copyright (C) 2004  Andrei Bulava <abulava@users.sourceforge.net>
 # Copyright (C) 2006  Igor Afanasyev <afan@mail.ru>
+# Copyright (c) 2007  Alexander Uvizhev <uvizhe@yandex.ru>
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -19,34 +20,42 @@
 #
 # This script was last checked for Oddmuse version 1.658.
 #
-$ModulesDescription .= '<p>$Id: russian-utf8.pl,v 1.9 2006/08/18 22:46:10 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: russian-utf8.pl,v 1.13 2007/08/19 11:42:08 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
+Просмотр недоступен: имя пользователя, IP-адрес или сеть заблокированы.
+Login
+
+Error
 
 %s calls
 
 Could not create %s
 Невозможно создать %s
 Invalid UserName %s: not saved.
-Hекорректная кличка %s: ничего не записано.
+Hекорректное имя пользователя %s: не сохранено.
 UserName must be 50 characters or less: not saved
-
+Имя пользователя не может содержать больше 50 символов: не сохранено
 This page contains an uploaded file:
 
 Recursive include of %s!
 
 Clear Cache
-
+Очистить кэш
 Main lock obtained.
 Блокировка сайта установлена.
 Main lock released.
 Блокировка сайта снята.
+Journal
+
+More...
+
 Comments on this page
 Комментарии к этой странице
 XML::RSS is not available on this system.
 
 diff
-отличия
+изменения
 history
 история
 %s returned no data, or LWP::UserAgent is not available.
@@ -58,11 +67,7 @@ No items found in %s.
  . . . . 
 
 Click to edit this page
-Щелчок - создать эту страницу
-image
-
-download
-
+Щелкните, чтобы править
 CGI Internal error: %s
 Внутренняя ошибка CGI: %s
 Invalid action parameter %s
@@ -85,6 +90,8 @@ Preview only, not yet saved
 Только предварительный просмотр - пока ничего не сохранено
 Please go on to %s.
 
+All changes for %s
+
 No updates since %s
 Не было обновлений с %s
 Updates since %s
@@ -100,17 +107,23 @@ List latest change per page only
 List all changes
 Показать все изменения
 Skip rollbacks
-
+Не показывать откаты
 Include rollbacks
-
+Включая откаты
 List only major changes
 Показать только существенные изменения
 Include minor changes
-Включить несущественные изменения
+Включая несущественные изменения
 %s days
 %s дней
 List later changes
 Показать недавние изменения
+RSS
+
+RSS with pages
+
+RSS with pages and diff
+
 Filters
 Фильтры
 Title:
@@ -121,6 +134,8 @@ Username:
 Имя пользователя:
 Host:
 Сервер:
+Follow up to:
+
 Language:
 Язык:
 Go!
@@ -133,6 +148,8 @@ new
 
 from %s
 с %s
+: 
+
 This page is too big to send over RSS.
 Эта страница слишком велика для трансляции в RSS.
 History of %s
@@ -142,11 +159,11 @@ Compare
 Deleted
 
 Mark this page for deletion
-
+Удалить эту страницу
 No other revisions available
 
 current
-
+текущая
 Revision %s
 Версия %s
 Contributors to %s
@@ -155,18 +172,20 @@ Missing target for rollback.
 
 Target for rollback is too far back.
 
+A username is required for ordinary users.
+
 Rolling back changes
-
+Откат изменений
 The two revisions are the same.
-
+Заданы одинаковые версии страницы
 Editing not allowed for %s.
 Редактирование не разрешено для %s.
 Rollback to %s
-
+Откат до %s
 %s rolled back
-
+%s восстановлена
 to %s
-
+до %s
 Index of all pages
 Каталог страниц
 Wiki Version
@@ -214,23 +233,23 @@ The same page on other sites:
 EditNearLinks
 
 Last edited
-Редактировалось в последний раз 
+Редактировалось последний раз 
 Edited
 Правленное
 by %s
 пользователем %s
 (diff)
-(отличия)
+(изменения)
 Edit revision %s of this page
 Править версию %s этой страницы
 Edit this page
-Редактировать текст этой страницы
+Редактировать
 e
 
 This page is read-only
 Эта страница предназначена только для чтения
 View other revisions
-Смотреть другие версии
+История
 View current revision
 Смотреть текущую версию
 View all changes
@@ -253,6 +272,8 @@ f
 
 Replace:
 Замена:
+Delete
+
 Validate HTML
 
 Validate CSS
@@ -260,7 +281,7 @@ Validate CSS
 Last edit
 
 Difference between revision %1 and %2
-Отличия (от версии %1 до %2)
+Отличия (версии %1 от %2)
 revision %s
 версии %s
 current revision
@@ -276,13 +297,13 @@ Old revision:
 Changed:
 Изменилось:
 Deleted:
-
+Удалено:
 Added:
 Добавлено:
 to
-
+на
 Revision %s not available
-Версия %s не доступна
+Версия %s недоступна
 showing current revision instead
 отображение текущей версии вместо
 Showing revision %s
@@ -322,7 +343,7 @@ No unlock required.
 just now
 
 Edit Denied
-
+Редактирование отклонено
 Editing not allowed: user, ip, or network is blocked.
 Редактирование не разрешено: пользователь, IP или сеть заблокированы.
 Contact the wiki administrator for more information.
@@ -344,9 +365,11 @@ Editing old revision %s.
 Saving this page will replace the latest revision with this text.
 Сохранение этой страницы заменит последнюю версию на этот текст.
 Summary:
-Итого:
+Описание:
 This change is a minor edit.
 Это изменение является незначительной правкой.
+Cancel
+Отмена
 Replace this file with text
 Заменить этот файл текстом
 Replace this text with a file
@@ -379,6 +402,10 @@ Sample_Undefined_Page
 Пример_Произвольной_Страницы
 Rule "%1" matched "%2" on this page.
 
+Reason: %s.
+
+Reason unknown.
+
 Without normal pages
 
 Include normal pages
@@ -424,23 +451,23 @@ Browser reports no file info.
 Browser reports no file type.
 
 The page contains banned text.
-
+Страница содержит запрещенный текст.
 No changes to be saved.
-
+Нечего сохранить.
 This page was changed by somebody else %s.
-
+Страница была изменена кем-то %s.
 The changes conflict.  Please check the page again.
-
+Изменения конфликтуют. Проверьте страницу снова.
 Please check whether you overwrote those changes.
 
 Anonymous
-
+Аноним
 Cannot delete the index file %s.
 
 Please check the directory permissions.
-
+Проверьте разрешения этой директории.
 Your changes were not saved.
-
+Ваши изменения не были сохранены.
 Could not get a lock to merge!
 
 you
@@ -539,6 +566,14 @@ Complete Content
 
 The main page is %s.
 
+Archive:
+
+Rebuild BackLink database
+
+Internal Page: 
+
+Pages that link to this page
+
 Cannot highlight the language %s.
 
 Recent Visitors
@@ -556,63 +591,71 @@ The match parameter is missing.
 Page Collection for %s
 
 Previous
-
+Назад
 Next
-
+Вперед
 Calendar %s
-
+Календарь за %s год
 Su
-
+Вс
 Mo
-
+Пн
 Tu
-
+Вт
 We
-
+Ср
 Th
-
+Чт
 Fr
-
+Пт
 Sa
-
+Сб
 January
-
+Январь
 February
-
+Февраль
 March
-
+Март
 April
-
+Апрель
 May
-
+Май
 June
-
+Июнь
 July
-
+Июль
 August
-
+Август
 September
-
+Сентябрь
 October
-
+Октябрь
 November
-
+Ноябрь
 December
+Декабрь
+set %s
+
+unset %s
 
 Clustermap
-
+Кластеры
 Pages without a Cluster
-
+Некластеризованые страницы
 Comments on 
-
+Комментарии к
 Comment on 
-
+Комментарий к
 Compilation for %s
 
 Compilation tag is missing a regular expression.
 
+List spammed pages
+
 Despamming pages
 
+Spammed pages
+
 Cannot find revision %s.
 
 Revert to revision %1: %2
@@ -621,10 +664,32 @@ Marked as %s.
 
 Cannot find unspammed revision.
 
-Add Comment
+Recover Draft
 
+No text to save
+
+Draft saved
+
+Draft recovered
+
+No draft available to recover
+
+Save Draft
+
+Draft Cleanup
+
+%1 was last modified %2 and was kept
+
+%1 was last modified %2 and was deleted
+
+Unable to delete draft %s
+
+Add Comment
+Комментировать
 ordinary changes
 
+Matching page names:
+
 Footnotes:
 
 Could not find %1.html template in %2
@@ -689,8 +754,6 @@ You are now logged out.
 
 Register a new account
 
-Login
-
 Logout
 
 Who am I?
@@ -749,6 +812,12 @@ There are no pending registrations.
 
 %s is not a legal name for a namespace
 
+ (create locally)
+
+image
+изображение
+download
+загрузить
 Clearing Cache
 
 Done.
@@ -797,12 +866,14 @@ The target wiki was misconfigured.
 
 You did not answer correctly.
 
+Use the back button to return the previous page and try again.
+
 To save this page you must answer this question:
 
-All Referrers
-
 Referrers
 
+All Referrers
+
 Tag
 
 Rebuild index for searching
@@ -831,6 +902,8 @@ No tags
 
 Slideshow:%s
 
+Index of all small pages
+
 Static Copy
 
 Back to %s
@@ -861,10 +934,14 @@ URL:
 
 Name:
 
-Failed to remove %s
+Too many instances.  Only %s allowed.
+
+Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.
 
 Contents
 
+Create a new page for today
+
 This page is a translation of %s. 
 
 The translation is up to date.
